CFile
-----

this is just a python module for making working with files in python not a pain in the ***

For a lsit of all the functions included simply type,
	$ cpfile.py --usage

Changelog

	-Fixed the module not working... at all
	-Added a cpfile.py command -then fixed it